@@ -3,7 +3,7 @@ package CracTools::Annotator;
   $CracTools::Annotator::DIST = 'CracTools';
 }
 # ABSTRACT: Generic annotation base on CracTools::GFF::Query::File
-$CracTools::Annotator::VERSION = '1.22';
+$CracTools::Annotator::VERSION = '1.24';
 use strict;
 use warnings;
 
@@ -46,8 +46,8 @@ sub mode {
 
 sub foundAnnotation {
   my $self = shift;
-  my ($chr,$pos_start,$pos_end,$strand) = @_;
-  my @candidates = @{ $self->getAnnotationCandidates($chr,$pos_start,$pos_end,$strand)};
+  #my ($chr,$pos_start,$pos_end,$strand) = @_;
+  my @candidates = @{ $self->getAnnotationCandidates(@_)};
   return (scalar @candidates > 0);
 }
 
@@ -218,7 +218,7 @@ sub getCandidatePriorityDefault {
   my ($priority,$type) = (-1,'');
   my ($mRNA,$exon) = ($candidate->{mRNA},$candidate->{exon});
   if(defined $mRNA) {
-    if($mRNA->attribute('type') =~ /protein_coding/i) {
+    if(defined $mRNA->attribute('type') && $mRNA->attribute('type') =~ /protein_coding/i) {
       if(defined $exon) {
         if(($exon->start <= $pos_start) && ($exon->end >= $pos_end)) {
           $priority = 1;
@@ -236,8 +236,8 @@ sub getCandidatePriorityDefault {
           $type = 'INXON';
         }
       } else {
-	$priority = 4;
-	$type = 'INTRON';
+        $priority = 4;
+        $type = 'INTRON';
       }
     } else {
       if(defined $exon) {
@@ -400,7 +400,7 @@ CracTools::Annotator - Generic annotation base on CracTools::GFF::Query::File
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 SYNOPSIS
 
@@ -670,7 +670,7 @@ Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
+This software is Copyright (c) 2016 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
