@@ -4,7 +4,7 @@ package CracTools::App::Command::Extract;
 }
 # ABSTRACT: Extract events identified by CRAC.
 # PODNAME: cractools extract
-$CracTools::App::Command::Extract::VERSION = '1.22';
+$CracTools::App::Command::Extract::VERSION = '1.24';
 use CracTools::App -command;
 
 use strict;
@@ -173,10 +173,10 @@ sub execute {
   # Print headers on output files
   print $splices_fh "track name=junctions\n" if defined $splices_fh;
   print $mutations_fh "##fileformat=VCFv4.1\n",
-    "###source=$CracTools::DIST (v $CracTools::VERSION)\n",
-    "###INFO=<ID=DP,Number=1,Type=Integer,Description=\"Total Depth\">\n",
-    "###INFO=<ID=AF,Number=A,Type=Float,Description=\"Allele Frequency\">\n",
-    "###INFO=<ID=CS,Number=A,Type=Float,Description=\"CRAC confidence score\">\n",
+    "##source=$CracTools::DIST (v $CracTools::VERSION)\n",
+    "##INFO=<ID=DP,Number=1,Type=Integer,Description=\"Total Depth\">\n",
+    "##INFO=<ID=AF,Number=A,Type=Float,Description=\"Allele Frequency\">\n",
+    "##INFO=<ID=CS,Number=A,Type=Float,Description=\"CRAC confidence score\">\n",
     "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\n" if defined $mutations_fh;
 
   for (my $region_id = 1; $region_id <= $nb_region; $region_id++) {
@@ -289,6 +289,7 @@ sub extractMutationsFromSAMline {
       my ($chr,$pos) = ($snp->{loc}->{chr},$snp->{loc}->{pos});
 
       # We only add SNPS that correspond to the current region
+      next if $chr ne $region_chr;
       next if $pos >= $region_end || $pos < $region_start;
 
       # This correspond to a 1bp deletion
@@ -305,6 +306,13 @@ sub extractMutationsFromSAMline {
         #$snp->{actual}    = substr $line->seq, $snp->{pos}-1, 2;
         $snp->{actual}    = getSeqOrNs($chr,$pos,1,$ref_file).substr $line->seq,$snp->{pos}, 1;
         $snp->{expected}  = substr $snp->{actual}, 0, 1; 
+      } else {
+        # If this this a regular SNP, we check if CRAC's reference is right, otherwise
+        # we have a problem in CRAC's calling prediction
+        if(defined $ref_file && $snp->{expected} ne getSeqOrNs($chr,$pos,1,$ref_file)) {
+          print STDERR "CRAC's SNP calling ($chr:$pos ".$snp->{expected}." => ".$snp->{actual}.") does not match the reference (".getSeqOrNs($chr,$pos,1,$ref_file)."), variant skipped (see read ".$line->qname." for more information)\n";
+          next;
+        }
       }
 
       # Uniq Hash key for SNP
@@ -569,7 +577,7 @@ cractools extract - Extract events identified by CRAC.
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head2 extractSplicesFromSAMline
 
@@ -609,7 +617,7 @@ Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
+This software is Copyright (c) 2016 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
