@@ -3,7 +3,7 @@ package CracTools::Const;
   $CracTools::Const::DIST = 'CracTools';
 }
 # ABSTRACT: Constants for the CracTools-core
-$CracTools::Const::VERSION = '1.22';
+$CracTools::Const::VERSION = '1.24';
 use strict;
 use warnings;
 use Exporter qw(import);
@@ -15,6 +15,12 @@ our $NOT_AVAILABLE = 'NA';
 our $NUCLEOTIDES = ['A', 'C', 'G', 'T' ];
 
 
+our $CRAC_BINARY = "crac";
+
+
+our $INDEX_DEFAULT = "/data/indexes/crac/GRCh38";
+
+
 1;
 
 __END__
@@ -29,7 +35,7 @@ CracTools::Const - Constants for the CracTools-core
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 SYNOPSIS
 
@@ -49,6 +55,10 @@ CracTools pipelines.
 
 =item NUCLEOTIDES => [ A, C, G, T ]
 
+=item CRAC_BINARY => "crac'
+
+=item INDEX_DEFAULT => "GRCh38"
+
 =back
 
 =head1 AUTHORS
@@ -71,7 +81,7 @@ Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
+This software is Copyright (c) 2016 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
