@@ -3,7 +3,7 @@ package CracTools::Utils;
   $CracTools::Utils::DIST = 'CracTools';
 }
 # ABSTRACT: A set of useful functions
-$CracTools::Utils::VERSION = '1.22';
+$CracTools::Utils::VERSION = '1.24';
 use strict;
 use warnings;
 
@@ -75,6 +75,71 @@ sub addChrPrefix($) {
 }
 
 
+our $Base64_BITNESS = 6;
+our @Base64_ENCODING = qw(A B C D E F G H I J K L M N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z 0 1 2 3 4 5 6 7 8 9 + /);
+
+# Encode error list into base64
+sub encodePosListToBase64 {
+  my @pos_list = @_;
+  my @bitList; 
+  my $encoded_str;
+
+  return "" if @pos_list == 0;
+
+  # Compute the appropriate length for the bitList
+  my $length = $pos_list[-1] + 1;
+  my $bitList_length = int($length / $Base64_BITNESS);
+  if ($length % $Base64_BITNESS > 0) {
+      $bitList_length++;
+  }
+
+  # Put 0 at all position
+  for (my $i = 0; $i < $bitList_length; $i++) {
+    $bitList[$i] = 0;
+  }
+
+  # Create bit vector in Base64_ENCODING
+  foreach my $j (@pos_list) {
+    $bitList[int($j / $Base64_BITNESS)] |= (1 << ($j % $Base64_BITNESS));
+  }
+  
+  # Convert bitList into string_Base64_ENCODING
+  for(my $k=0; $k < $bitList_length; $k++) {
+    $encoded_str .= scalar($Base64_ENCODING[$bitList[$k]]); 
+  }
+  return $encoded_str;
+}
+
+
+# Decode base 64 error list
+sub decodePosListInBase64 {
+  my $encoded_str = shift;
+
+  my @encoded_list = split "", $encoded_str;
+  my (@index,@decoded_list);
+
+  #Looking for index of each char
+  foreach my $j (@encoded_list) {
+    my @ind = grep { $Base64_ENCODING[$_] eq $j } 0 .. $#Base64_ENCODING;
+    push(@index,$ind[0]);
+  }
+
+  # Convert into list position     
+  for (my $e = 0; $e < (0+@encoded_list);$e++) {
+    for(my $i=0; $i<$Base64_BITNESS; $i++) {
+      if ($index[$e] & (1 << $i)) {
+        my $pos = (int($i+$Base64_BITNESS*$e));
+        push(@decoded_list,$pos);
+      }
+    }
+  }  
+
+  return @decoded_list; 
+}
+
+
+
+
 sub seqFileIterator {
   my ($file,$format) = @_;
 
@@ -344,7 +409,8 @@ sub parseChimCTLine {
   }                                                                       
   return {                                                                
     sample            => $sample,                                                    
-    chim_key          => $chim_key,                                                
+    chim_key          => $chim_key,
+    name              => $name,
     chr1              => $chr1,                                                        
     pos1              => $pos1,                                                        
     strand1           => $strand1,                                                  
@@ -383,6 +449,16 @@ sub parseSAMLineLite {
 }
 
 
+sub parseCigarChain {
+  my $cigar_string = shift;
+  my @cigar;
+  while($cigar_string =~ /(\d+)(\S)/g) {
+    push @cigar, { op => $2, nb => $1 };
+  }
+  return \@cigar;
+}
+
+
 
 sub getFileIterator {
   my %args = @_;
@@ -455,6 +531,7 @@ sub getFileIterator {
       my $parsed_line = $parsing_method->($line,@parsing_arguments);
       # Add seek pos to the output hashref
       $parsed_line->{seek_pos} = $curr_pos;
+      $parsed_line->{_original_line} = $line;
       $curr_pos = tell($fh);
       $line = <$fh>; # Get next line
       return $parsed_line;
@@ -511,7 +588,7 @@ CracTools::Utils - A set of useful functions
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 SYNOPSIS
 
@@ -612,6 +689,20 @@ will print
 
 Add the "chr" prefix to the given string
 
+=head1 ENCODING
+
+=head2 encodePosListToBase64
+
+Encode a (0-based) list of increasing position to a string using Base64
+encoding scheme : ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/
+
+  my $encoded_list = CracTools::Utils::encodePosListToBase64(1,3,5,8,12,32);
+  my @decoded_list = CracTools::Utils::decodePosListInBase64($encoded_list);
+
+=head2 decodePosListInBase64
+
+Decode position list encoded by encodePosListToBase64.
+
 =head1 PARSING
 
 This are some tools that aim to read (bio) files like
@@ -767,6 +858,7 @@ Return a hashref with the chimera parsed:
   {
     sample            => $sample,                                                    
     chim_key          => $chim_key,                                                
+    name              => $name,
     chr1              => $chr1,                                                        
     pos1              => $pos1,                                                        
     strand1           => $strand1,                                                  
@@ -778,7 +870,7 @@ Return a hashref with the chimera parsed:
     spanning_PE       => $spanning_PE,                                          
     class             => $class,                                                      
     comments          => { coment_id => 'comment_value', ... },
-    extend_fields     => { extend_field_id => 'extend_field_value', ... },
+    extended_fields     => { extended_field_id => 'extended_field_value', ... },
   }
 
 =head2 bamFileIterator
@@ -823,10 +915,17 @@ Example:
 
 =head2 parseSAMLineLite
 
+=head2 parseCigarChain
+
+Given a CIGAR chain (see SAM specification), return a parsed version as an Array ref of 
+cigar elements represented as { nb => 10, op => 'M' }.
+
 =head1 FILES IO
 
 =head2 getFileIterator
 
+Generic method to parse files.
+
 =head2 getReadingFileHandle
 
 Return a file handle for the file in argument.
@@ -877,7 +976,7 @@ Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
+This software is Copyright (c) 2016 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
